@@ -70,7 +70,7 @@
 #endif
 
 extern int
-WriteAsciiPNMfd(FILE * fd, Image * image);
+WriteAsciiPNMtoFD(FILE * fd, Image * image);
 
 extern Widget
 createBrushDialog(Widget w);
@@ -251,8 +251,8 @@ setPatternColorsIcon(LocalInfo * l)
 	    if (y<4 || y>ICONHEIGHT-5) {
                 x0[y] = ICONWIDTH;
 	    } else
-                x0[y] = 11+abs(y-20)/3;
-                x1[y] = ICONWIDTH-3-abs(y-20)/3;
+                x0[y] = 11+abs(y-ICONHEIGHT/2)/3;
+                x1[y] = ICONWIDTH-3-abs(y-ICONHEIGHT/2)/3;
 	}
     }
     for (y=0; y<ICONHEIGHT; y++) {
@@ -393,6 +393,7 @@ initViews(LocalInfo * info)
 
     XtVaGetValues(info->fat, XtNfillRule, &rule, 
 		             XtNforeground, &p, NULL);
+   
     if (rule == FillSolid && p != BlackPixelOfScreen(XtScreen(info->view1)))
         ColorPickerSetPixel(info->cpick, p);
     setPatternColorsIcon(info);
@@ -457,7 +458,7 @@ saveConfigOkCallback(Widget il, LocalInfo * info, char *file)
 
 	    fprintf(fd, "pattern BeginData\n");
 	    image = PixmapToImage(info->fat, pi->pixmap, cmap);
-	    WriteAsciiPNMfd(fd, image);
+	    WriteAsciiPNMtoFD(fd, image);
 	    ImageDelete(image);
 	    fprintf(fd, "\nEndData\n");
 	}
@@ -465,13 +466,13 @@ saveConfigOkCallback(Widget il, LocalInfo * info, char *file)
 
     for (i = 0; i < info->nbrushes; i++) {
 	fprintf(fd, "brush BeginData\n");
-	WriteAsciiPNMfd(fd, info->brushes[i]);
+	WriteAsciiPNMtoFD(fd, info->brushes[i]);
 	fprintf(fd, "\nEndData\n");
     }
 
     for (i = 0; i < Global.nbrushes; i++) {
 	fprintf(fd, "brush BeginData\n");
-	WriteAsciiPNMfd(fd, (Image *)(Global.brushes[i]));
+	WriteAsciiPNMtoFD(fd, (Image *)(Global.brushes[i]));
 	fprintf(fd, "\nEndData\n");
     }
 
@@ -491,16 +492,20 @@ static void
 loadConfigOkCallback(Widget il, LocalInfo * info, char *file)
 {
     RCInfo *rcInfo = ReadRC(file);
+    Dimension width, height;
     if (rcInfo == NULL) {
 	Notice(Global.patternshell, msgText[UNABLE_TO_OPEN_FILE], file);
 	return;
     }
     XawToggleUnsetCurrent(info->patternlist);
+    XtVaGetValues(info->patternbox,
+		  XtNwidth, &width, XtNheight, &height, NULL);
     XtDestroyWidget(info->patternbox);
     info->patternlist = None;
     info->patternbox = XtVaCreateManagedWidget("patternRack",
-			            boxWidgetClass, info->vport,
-				    XtNforceBars, True,
+			            boxWidgetClass, info->vport2,
+				    XtNwidth, width, XtNheight, height,
+				    XtNforceBars, False,
 			            NULL);
     makePaletteArea(info, rcInfo);
     FreeRC(rcInfo);
@@ -518,6 +523,7 @@ static void
 activePixel(LocalInfo * l, Pixel p)
 {
     char *w_fr, *w_fg;
+    
 
     if (!l->active) return;
     XtVaSetValues(l->active, XtNbackgroundPixmap, XtUnspecifiedPixmap, NULL);
@@ -526,10 +532,18 @@ activePixel(LocalInfo * l, Pixel p)
     if (l->active == l->view1) {
 	w_fr = XtNfillRule;
 	w_fg = XtNforeground;
-	l->mask &= 2;
+        if (DoVxp(l->paint) & (l->mask & 1)) {
+           sprintf(Global.vxpinput, "\n*color1 %06lx", p);
+ 	   RecordVxp(l->paint);
+        }
+	l->mask &= 2;	
     } else {
 	w_fr = XtNlineFillRule;
 	w_fg = XtNlineForeground;
+        if (DoVxp(l->paint) && (l->mask & 2)) {
+           sprintf(Global.vxpinput, "\n*color2 %06lx", p);
+ 	   RecordVxp(l->paint);
+        }	
 	l->mask &= 1;
     }
     if (l->paint)
@@ -549,7 +563,7 @@ patternUpdate(PatternInfo * info)
     char *w_fr, *w_fg, *w_pat;
     Display *dpy;
     Pixmap pix=None, npix;
-    int rule=-1;
+    int i, rule=-1;
 
     if (!info->li->active) return;
     if (info->li->active == info->li->view1) {
@@ -557,11 +571,13 @@ patternUpdate(PatternInfo * info)
 	w_fg = XtNforeground;
 	w_pat = XtNpattern;
 	info->li->mask |= 1;
+	i = 1;
     } else {
 	w_fr = XtNlineFillRule;
 	w_fg = XtNlineForeground;
 	w_pat = XtNlinePattern;
         info->li->mask |= 2;
+	i = 2;
     }
 
     if (info->pixmap == None)
@@ -583,6 +599,10 @@ patternUpdate(PatternInfo * info)
         XtVaSetValues(info->li->active, 
                       XtNbackgroundPixmap, npix, NULL);
         if (rule==FillTiled && pix) XFreePixmap(dpy, pix);
+        if (DoVxp(info->li->paint)) {
+	   sprintf(Global.vxpinput, "\n*pattern%d %d", i, npix);
+ 	   RecordVxp(info->li->paint);
+        }			
     }
     setPatternColorsIcon(info->li);
     setCanvasColorsIcon(info->li->paint, NULL);
@@ -694,32 +714,20 @@ void
 patternResized(Widget w, LocalInfo * l, XConfigureEvent * event, Boolean * flg)
 {
     Dimension width, height;
-    Dimension height1, height2;
+    int dim, height1, height2;
 
-    XFlush(XtDisplay(l->form));   
+    XFlush(XtDisplay(l->form));
     w = XtParent(l->form);
     if (!w) return;
     XtVaGetValues(w, XtNwidth, &width, XtNheight, &height, NULL);
-    if (width<400) width = 400;
+    if (width<500) width = 500;
     if (height<300) height = 300;
-#ifdef XAW3DXFT
-    height1 = (height-ICONHEIGHT - 10) * 2/3;
+    XtVaGetValues(l->fat, XtNdrawHeight, &height1, NULL);
+    height1 = height1 * 7 + Global.btn_height;
+    if (height1 < 6*Global.btn_height + 220)
+        height1 = 6*Global.btn_height + 220;
     height2 = height - height1 - ICONHEIGHT - 15;
-#else    
-#ifdef XAW3D
-    height1 = ((height-ICONHEIGHT)*265)/480;
-#ifdef XAW3DG
-    if (height1<271) height1 = 271;
-#else
-    if (height1<268) height1 = 268;   
-#endif   
-    height2 = ((height-61)*208)/480;
-#else   
-    height1 = ((height-69)*276)/480;
-    if (height1<276) height1 = 276;    
-    height2 = ((height-59)*196)/480;
-#endif
-#endif    
+    if (height2 < 50) height2 = 50;
     XtResizeWidget(l->form, width-8, height1, 1);
     XtMoveWidget(l->form, 4, ICONHEIGHT+10);
     XtResizeWidget(l->form1, width-8, height2, 1);
@@ -730,8 +738,17 @@ patternResized(Widget w, LocalInfo * l, XConfigureEvent * event, Boolean * flg)
     XtResizeWidget(l->vport, width-345, height1-32, 0);   
     XtResizeWidget(l->box, width-345, height1-32, 0);
 #endif
+#ifdef XAW3DXFT
+    dim = width - 15*Global.btn_height -90;
+    if (dim < 20) dim = 20;
+    XtResizeWidget(l->vport, dim + 30, height1 - Global.btn_height - 14, 0);
+    XtManageChild(l->box);
+    XtResizeWidget(l->box, dim, height1 - Global.btn_height + 16, 0);
+    XtUnmanageChild(l->box);
+    XMapWindow(XtDisplay(l->box), XtWindow(l->box));
+#endif
 #ifdef XAW3D   
-    XtResizeWidget(l->vport, width-330, height1-18, 1);
+    XtResizeWidget(l->vport, width-330, height1-18, 0);
     XtResizeWidget(l->box, width-330, height1-18, 0);
 #endif
 #ifdef XAW95
@@ -1108,6 +1125,51 @@ setAsBackgroundCallback(Widget w, LocalInfo * l, XPointer * junk2)
     activePixel(l, p);
 }
 
+static void 
+exchangeCallback(Widget w, LocalInfo * l, XPointer * junk2)
+{
+  Pixel p1, p2;
+  Pixmap pix1, pix2;
+  int v_fr, v_lfr;
+  pix1 = None;
+  pix2 = None;
+  XtVaGetValues(l->view1, XtNbackground, &p1,
+		XtNbackgroundPixmap, &pix1, NULL);
+  XtVaGetValues(l->view2, XtNbackground, &p2,
+		XtNbackgroundPixmap, &pix2, NULL);
+  XtVaSetValues(l->view1, XtNbackground, p2,
+		XtNbackgroundPixmap, pix2, NULL);
+  XtVaSetValues(l->view2, XtNbackground, p1,
+		XtNbackgroundPixmap, pix1, NULL);
+
+  XtVaGetValues(l->fat, XtNfillRule, &v_fr, XtNlineFillRule, &v_lfr, NULL);
+  XtVaSetValues(l->fat, XtNfillRule, v_lfr, XtNlineFillRule, v_fr, NULL);
+  XtVaSetValues(l->fat, XtNforeground, p2, NULL);
+  XtVaSetValues(l->fat, XtNlineForeground, p1, NULL);
+  XtVaGetValues(l->paint, XtNfillRule, &v_fr, XtNlineFillRule, &v_lfr, NULL);
+  XtVaSetValues(l->paint, XtNfillRule, v_lfr, XtNlineFillRule, v_fr, NULL);  
+  XtVaSetValues(l->paint, XtNforeground, p2, NULL);
+  XtVaSetValues(l->paint, XtNlineForeground, p1, NULL);
+  if (pix2 && pix2 != XtUnspecifiedPixmap)
+     XtVaSetValues(l->fat, XtNpattern, pix2, NULL);
+  if (pix1 && pix1 != XtUnspecifiedPixmap)
+     XtVaSetValues(l->fat, XtNlinePattern, pix1, NULL);
+  pix1 = None;
+  pix2 = None;
+  XtVaGetValues(l->paint, XtNpattern, &pix1, XtNlinePattern, &pix2, NULL);   
+  if (pix2 && pix2 != XtUnspecifiedPixmap)  
+    XtVaSetValues(l->paint, XtNpattern, pix2, NULL);
+  if (pix1 && pix1 != XtUnspecifiedPixmap)
+    XtVaSetValues(l->paint, XtNlinePattern, pix1, NULL);    
+  setPatternColorsIcon(l);
+  setCanvasColorsIcon(l->fat, NULL);  
+  setCanvasColorsIcon(l->paint, NULL);
+  if (DoVxp(l->paint)) {
+     strcpy(Global.vxpinput, "\n*switchpatterns");
+     RecordVxp(l->paint);
+  }
+}
+
 static void 
 colorSelectCallback(Widget w, LocalInfo * l, XPointer * junk2)
 {
@@ -1481,6 +1543,7 @@ sizeCallback(Widget w, XtPointer larg, XtPointer junk)
      */
     XtVaSetValues(l->fat, XtNdrawWidth, width,
 		  XtNdrawHeight, height, NULL);
+    patternResized(l->fat, l, NULL, 0);
 }
 
 static void 
@@ -1819,8 +1882,7 @@ PatternEdit(Widget w, Pixel *pixels, Pixmap *patterns, void *brushes,
 
     info->form = XtVaCreateManagedWidget("patternbox", formWidgetClass, topf,
 				   XtNfromVert, info->view1,
-				   NULL);
-
+				   NULL);    
     cpick = None;
 
     if (!map->isMapped || !map->readonly_ || map->ncolors > 256)
@@ -1869,7 +1931,7 @@ PatternEdit(Widget w, Pixel *pixels, Pixmap *patterns, void *brushes,
 			         XtNtop, XtChainTop,
 				 XtNbottom, XtChainBottom,
 				 XtNwidth, 286,
-				 XtNheight, 250,
+				 XtNheight, 344,
 				 NULL);
 
     if (cpick != None) {
@@ -1920,6 +1982,8 @@ PatternEdit(Widget w, Pixel *pixels, Pixmap *patterns, void *brushes,
 	    (XtCallbackProc) colorSelectCallback, (XtPointer) info);
 	XtAddCallback(ColorPickerGetAsBgWidget(cpick), XtNcallback,
 	    (XtCallbackProc) setAsBackgroundCallback, (XtPointer) info);
+	XtAddCallback(ColorPickerGetExchangeWidget(cpick), XtNcallback,
+	    (XtCallbackProc) exchangeCallback, (XtPointer) info);
     }
 
     if (cpick != None) {
@@ -2023,7 +2087,7 @@ PatternEdit(Widget w, Pixel *pixels, Pixmap *patterns, void *brushes,
 				   formWidgetClass, topf,
 				   XtNfromVert, info->form,
 				   NULL);
-
+    
     info->form2 = XtVaCreateManagedWidget("patternRackForm",
 				   formWidgetClass, info->form1,
 				   XtNborderWidth, 0,
@@ -2068,6 +2132,7 @@ PatternEdit(Widget w, Pixel *pixels, Pixmap *patterns, void *brushes,
     XtUnmanageChild(info->view1);
     XtUnmanageChild(info->view2);
     XtUnmanageChild(info->icon);
+    XtUnmanageChild(info->box);    
     XtUnmanageChild(cancel);
 
     XtVaGetValues(Global.patternshell, XtNbackground, &bgpix, NULL);
@@ -2097,14 +2162,16 @@ PatternEdit(Widget w, Pixel *pixels, Pixmap *patterns, void *brushes,
     XMapWindow(dpy, XtWindow(asbrushPattern));
     XMapWindow(dpy, XtWindow(info->form));   
     XMapWindow(dpy, XtWindow(info->form1));
-    XMapWindow(dpy, XtWindow(info->form2));      
+    XMapWindow(dpy, XtWindow(info->form2));
     XMapWindow(dpy, XtWindow(info->view1));
     XMapWindow(dpy, XtWindow(info->view2));
     XMapWindow(dpy, XtWindow(info->vport2));
     XMapWindow(dpy, XtWindow(info->icon));
-    XMapWindow(dpy, XtWindow(cancel));   
+    XMapWindow(dpy, XtWindow(info->box));    
+    XMapWindow(dpy, XtWindow(cancel));
     XMapWindow(dpy, XtWindow(info->r_arrow));
     XUnmapWindow(dpy, XtWindow(info->g_arrow));
+
     initViews(info);
 
     XtVaGetValues(info->paint, XtNlineWidth, &nargs, NULL);
