@@ -23,11 +23,12 @@ void StdRegionFlipX(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionFlipY(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionDelimit(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionComplement(Widget w, XtPointer paintArg, XtPointer junk2);
-void StdRegionClone(Widget w, XtPointer paintArg, XtPointer junk2);
+void StdRegionEdit(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdLastImgProcess(Widget paint);
 
 void StdRegionInvert(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionSharpen(Widget w, XtPointer paintArg, XtPointer junk2);
+void StdRegionMerge(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionSmooth(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionEdge(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionEmboss(Widget w, XtPointer paintArg, XtPointer junk2);
@@ -37,18 +38,22 @@ void StdRegionSpread(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionBlend(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionPixelize(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionDespeckle(Widget w, XtPointer paintArg, XtPointer junk2);
-void StdRegionNormContrast(Widget w, XtPointer paintArg, XtPointer junk2);
+void StdRegionNormalizeContrast(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionSolarize(Widget w, XtPointer paintArg, XtPointer junk2);
+void StdRegionToRGBAComponents(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionModifyRGB(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionGrey(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionBWMask(Widget w, XtPointer paintArg, XtPointer junk2);
+void StdRegionGammaCorrection(Widget w, XtPointer paintArg, XtPointer junk2);
+void StdRegionFloydSteinberg(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionQuantize(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionExpand(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionDownscale(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionUserDefined(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionDirFilt(Widget w, XtPointer paintArg, XtPointer junk2);
 void StdRegionUndo(Widget w, XtPointer paintArg, XtPointer junk2);
-void StdRegionTilt(Widget w, XtPointer paintArg, XtPointer junk2);
+void StdRegionDistort(Widget w, XtPointer paintArg, XtPointer junk2);
+void StdRegionProjTransform(Widget w, XtPointer paintArg, XtPointer junk2);
 #ifdef __IMAGE_H__
 Image *ImgProcessSetup(Widget paint);
 Image *ImgProcessFinish(Widget paint, Image * in, Image * (*func) (Image *));
@@ -65,7 +70,7 @@ void ccpAddDuplicate(Widget w, Widget paint);
 void ccpAddSelectAll(Widget w, Widget paint);
 void ccpAddEraseAll(Widget w, Widget paint);
 void ccpAddSaveRegion(Widget w, Widget paint);
-void ccpAddCloneRegion(Widget w, Widget paint);
+void ccpAddEditRegion(Widget w, Widget paint);
 void ccpAddOCRRegion(Widget w, Widget paint);
 void ccpAddRegionFlipX(Widget w, Widget paint);
 void ccpAddRegionFlipY(Widget w, Widget paint);
@@ -78,7 +83,8 @@ void ccpAddRegionNoise(Widget w, Widget paint);
 void ccpAddRegionBlend(Widget w, Widget paint);
 void ccpAddStdPopup(Widget paint, void *info);
 
-void RegionCrop(PaintWidget paint);
+void RegionCrop(PaintWidget pw);
+void RegionCreateMask(PaintWidget pw);
 void RegionMove(PaintWidget pw, int dx, int dy);
 void RegionTransparency(PaintWidget pw);
 
