@@ -19,4 +19,5 @@
 #include "XPAINT_SHAREDIR/include/print.h"
 #include "XPAINT_SHAREDIR/include/region.h"
 #include "XPAINT_SHAREDIR/include/text.h"
-
+#include "XPAINT_SHAREDIR/include/xpaintrw.h"
+#include "XPAINT_SHAREDIR/include/rwTable.h"
